<?php

namespace phil\HabboFont2\cache;

use phil\HabboFont2\artist\BlankImage;
use phil\HabboFont2\Config;
use phil\HabboFont2\fonts\Font;

class Cache {

	private static $_instance = null;

	public static function get($save_path = Config::SAVE_PATH) {

		if (self::$_instance == null) {
			self::$_instance = new self($save_path);
		}

		return self::$_instance;
	}

	private $_savePath = null;

	public function __construct($save_path) {

		$this->_savePath = $save_path;
	}

	private function getDirectoryPath(array $info) {

		$font_type = $info["font"];
		$addons = $info["addons"];

		$addon_directory = "ADDONS:";
		foreach ($addons as $addon) {
			$addon_directory .= md5(get_class($addon));
		}

		$dir = __DIR__ . '/../' . $this->_savePath . md5(get_class($font_type)) . '/' . md5($addon_directory);

		return $dir;
	}

	public function getByInfo(array $info) {

		$directory_path = $this->getDirectoryPath($info);
		$file_path = $directory_path . '/' . md5($info["text"]) . ".png";
		if (is_dir($directory_path) && file_exists($file_path)) {
			return new CacheImage($file_path);
		} else {
			return null;
		}
	}

	public function save(BlankImage $blankImage, Font $font, $text) {

		$directory_path = $this->getDirectoryPath([
			"font" => $font,
			"addons" => $font->getActiveAddons()
		]);

		if (!file_exists($directory_path)) {
			mkdir($directory_path, 777, true);
		}

		imagePNG($blankImage->getImage(), $directory_path . '/' . md5($text) . ".png");

		return $this->getByInfo([
			"font" => $font,
			"addons" => $font->getActiveAddons(),
			"text" => $text
		]);
	}

}